#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators.TradeSaber.Samples
{
	public class ColorHorizontalLinesPlot : Indicator
	{
		private string author 								= "TradeSaber(Dre) // Samples";
		private string version 								= "Version 1.0 // December 2022";
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Enter the description for your new custom Indicator here.";
				Name										= "ColorHorizontalLinesPlot";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= true;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				
				SplitPlots									= true;
				
				SupportLine									= 3975;
				AbovePrice									= Brushes.LimeGreen;
				BelowPrice									= Brushes.DarkRed;
				
				AddPlot(Brushes.SkyBlue, "Support");
				Plots[0].Width 								= 2;
			}
			else if (State == State.Configure)
			{
			}
		}

		protected override void OnBarUpdate()
		{
			//Uses Plots on the same price to create a line. Splits color depending on where each bar price closes.
			if (SplitPlots)
			{
				Values[0][0] = SupportLine;
				
				if (Close[0] > SupportLine)
				{
					PlotBrushes[0][0] = AbovePrice;	
				}
				
				else if (Close[0] < SupportLine)
				{
					PlotBrushes[0][0] = BelowPrice;	
				}
			
				else
				{
					PlotBrushes[0][0] = Brushes.Black;	
				}
			}
			
			//Uses Plots on the same price to create a line. Changes entire color depending on where the current price closes.
			if (SplitPlots == false)
			{
				Value[0] = SupportLine;

				if (Close[0] > SupportLine)
				{
					Plots[0].Brush = AbovePrice;
				}
				
				else if (Close[0] < SupportLine)
				{
					Plots[0].Brush = BelowPrice;
				}
				
				else
				{
					Plots[0].Brush = Brushes.Black;
				}
			}
			
		}
		
		#region Properties
		
		[NinjaScriptProperty]
		[Display(Name="SplitPlots", Order=0, GroupName="1. Parameters")]
		public bool SplitPlots
		{ get; set; }
		
		[NinjaScriptProperty]
		[Display(Name="SupportLine", Order=1, GroupName="1. Parameters")]
		public double SupportLine
		{ get; set; }
		
		[XmlIgnore()]
		[Display(Name = "AbovePrice", GroupName = "1. Parameters", Order = 2)]
		public Brush AbovePrice
		{ get; set; }
		
		// Serialize our Color object
		[Browsable(false)]
		public string AbovePriceSerialize
		{
			get { return Serialize.BrushToString(AbovePrice); }
   			set { AbovePrice = Serialize.StringToBrush(value); }
		}
		
		[XmlIgnore()]
		[Display(Name = "BelowPrice", GroupName = "1. Parameters", Order = 3)]
		public Brush BelowPrice
		{ get; set; }
		
		// Serialize our Color object
		[Browsable(false)]
		public string BelowPriceSerialize
		{
			get { return Serialize.BrushToString(BelowPrice); }
   			set { BelowPrice = Serialize.StringToBrush(value); }
		}
		
		
		[NinjaScriptProperty]
		[ReadOnly(true)]
		[Display(Name = "Author", GroupName = "29. TradeSaber Socials", Order = 4)]
		public string Author
		{
		 	get{return author;} 
			set{author = (value);} 
		}
		
		[NinjaScriptProperty]
		[ReadOnly(true)]
		[Display(Name = "Version", GroupName = "29. TradeSaber Socials", Order = 5)]
		public string Version
		{
		 	get{return version;} 
			set{version = (value);} 
		}
		#endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private TradeSaber.Samples.ColorHorizontalLinesPlot[] cacheColorHorizontalLinesPlot;
		public TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(bool splitPlots, double supportLine, string author, string version)
		{
			return ColorHorizontalLinesPlot(Input, splitPlots, supportLine, author, version);
		}

		public TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(ISeries<double> input, bool splitPlots, double supportLine, string author, string version)
		{
			if (cacheColorHorizontalLinesPlot != null)
				for (int idx = 0; idx < cacheColorHorizontalLinesPlot.Length; idx++)
					if (cacheColorHorizontalLinesPlot[idx] != null && cacheColorHorizontalLinesPlot[idx].SplitPlots == splitPlots && cacheColorHorizontalLinesPlot[idx].SupportLine == supportLine && cacheColorHorizontalLinesPlot[idx].Author == author && cacheColorHorizontalLinesPlot[idx].Version == version && cacheColorHorizontalLinesPlot[idx].EqualsInput(input))
						return cacheColorHorizontalLinesPlot[idx];
			return CacheIndicator<TradeSaber.Samples.ColorHorizontalLinesPlot>(new TradeSaber.Samples.ColorHorizontalLinesPlot(){ SplitPlots = splitPlots, SupportLine = supportLine, Author = author, Version = version }, input, ref cacheColorHorizontalLinesPlot);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(bool splitPlots, double supportLine, string author, string version)
		{
			return indicator.ColorHorizontalLinesPlot(Input, splitPlots, supportLine, author, version);
		}

		public Indicators.TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(ISeries<double> input , bool splitPlots, double supportLine, string author, string version)
		{
			return indicator.ColorHorizontalLinesPlot(input, splitPlots, supportLine, author, version);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(bool splitPlots, double supportLine, string author, string version)
		{
			return indicator.ColorHorizontalLinesPlot(Input, splitPlots, supportLine, author, version);
		}

		public Indicators.TradeSaber.Samples.ColorHorizontalLinesPlot ColorHorizontalLinesPlot(ISeries<double> input , bool splitPlots, double supportLine, string author, string version)
		{
			return indicator.ColorHorizontalLinesPlot(input, splitPlots, supportLine, author, version);
		}
	}
}

#endregion
